@@ -25,6 +25,7 @@ import testtools
 from pifpaf.drivers import aodh
 from pifpaf.drivers import ceph
 from pifpaf.drivers import consul
+from pifpaf.drivers import couchdb
 from pifpaf.drivers import elasticsearch
 from pifpaf.drivers import etcd
 from pifpaf.drivers import fakes3
@@ -75,12 +76,28 @@ class TestDrivers(testtools.TestCase):
                           "etcd not found")
     def test_etcd(self):
         port = 4005
-        self.useFixture(etcd.EtcdDriver(port=port))
+        peer_port = 4006
+        self.useFixture(etcd.EtcdDriver(port=port, peer_port=peer_port))
         self.assertEqual("etcd://localhost:%d" % port,
                          os.getenv("PIFPAF_URL"))
         self.assertEqual(str(port), os.getenv("PIFPAF_ETCD_PORT"))
         r = requests.get("http://localhost:%d/version" % port)
         self.assertEqual(200, r.status_code)
+        self._run("etcdctl cluster-health")
+
+    @testtools.skipUnless(spawn.find_executable("etcd"),
+                          "etcd not found")
+    def test_etcd_cluster(self):
+        port = 4007
+        peer_port = 4008
+        self.useFixture(etcd.EtcdDriver(port=port, peer_port=peer_port,
+                                        cluster=True))
+        self.assertEqual("etcd://localhost:%d" % port,
+                         os.getenv("PIFPAF_URL"))
+        self.assertEqual(str(port), os.getenv("PIFPAF_ETCD_PORT"))
+        r = requests.get("http://localhost:%d/version" % port)
+        self.assertEqual(200, r.status_code)
+        self._run("etcdctl cluster-health")
 
     @testtools.skipUnless(spawn.find_executable("consul"),
                           "consul not found")
@@ -140,15 +157,15 @@ class TestDrivers(testtools.TestCase):
     def test_mysql(self):
         f = self.useFixture(mysql.MySQLDriver())
         self.assertEqual(
-            "mysql://root@localhost/test?unix_socket=%s/mysql.socket"
+            "mysql://root@localhost/pifpaf?unix_socket=%s/mysql.socket"
             % f.tempdir,
             os.getenv("PIFPAF_URL"))
         self.assertEqual(
-            "mysql://root@localhost/test?unix_socket=%s/mysql.socket"
+            "mysql://root@localhost/pifpaf?unix_socket=%s/mysql.socket"
             % f.tempdir,
             f.url)
         self._run(
-            "mysql --no-defaults -S %s -e 'SHOW TABLES;' test" % f.socket)
+            "mysql --no-defaults -S %s -e 'SHOW TABLES;' pifpaf" % f.socket)
 
     @testtools.skipUnless(spawn.find_executable("pg_config"),
                           "pg_config not found")
@@ -310,3 +327,13 @@ class TestDrivers(testtools.TestCase):
         a.kill_node(a.nodename + "-2@localhost")
         a.stop_node(a.nodename + "-3@localhost")
         a.start_node(a.nodename + "-3@localhost")
+
+    @testtools.skipUnless(spawn.find_executable("couchdb"),
+                          "CouchDB not found")
+    def test_couchdb(self):
+        port = 6984
+        self.useFixture(couchdb.CouchDBDriver(port=port))
+        self.assertEqual("couchdb://localhost:%d" % port,
+                         os.getenv("PIFPAF_URL"))
+        r = requests.get("http://localhost:%d/" % port)
+        self.assertEqual(r.json()["couchdb"], "Welcome")
